#
# This following example shows how to get synchronization status of specified HA device and 
# if there is a need run synchronization
#
Import-Module StarWindX

try
{
    #
    # connect to the server
    #
    $server = New-SWServer -host 10.1.1.10 -port 3261 -user root -password starwind

    $server.Connect()

    #
    # Try to find specified device
    #
    $deviceName = "HAImage1"
    $partnerTargetName = "iqn.2008-08.com.starwindsoftware:10.1.1.10-partnerdata1"
    $deviceFound = $false
    
    foreach($device in $server.devices)
    {
        if ($device.name -eq $deviceName)
        {
            Write-Host "$($deviceName)" -foreground yellow
            Write-Host ""

            $deviceFound = $true
            $syncState = $device.GetPropertyValue("ha_synch_status")

            while ($syncState -ne "1")
            {
                #
                # Device not synchronized. Maybe it waiting for autosynchronization ?
                #
                $waitForAutoSync = $device.GetPropertyValue("ha_wait_on_autosynch")
                
                if ( $waitForAutoSync -eq "1" )
                {
                    Write-Host "Waiting for autosynchronization..." -foreground yellow
                }
                else
                {
                    if ( $syncState -eq "2" )
                    {
                        #
                        # Device is synchronizing. Get synchronization percent and show it
                        #
                        $syncPercent = $device.GetPropertyValue("ha_synch_percent")
                        
                        Write-Host "Synchronizing: $($syncPercent)%" -foreground yellow
                    }
                    
                    if ( $syncState -eq "3" )
                    {
                        #
                        # Device not synchronized. Synchronize current node from partner
                        #
                        Write-Host "Device not synchronized. Synchronize current node from partner '$($partnerTargetName)'" -foreground yellow

                        $params = new-object -ComObject StarWindX.Parameters        
                        $params.AppendParam("deviceID",$device.DeviceId)
                        $params.AppendParam("partnetTargetName",$partnerTargetName)
                        
                        $server.ExecuteCommand( 0, "restoreHAPartnerNode", $params)
                        
                        #
                        # If you want to synchronize partners from current node you can comment out code above and uncomment section below
                        #
                        
                        #
                        # Device not synchronized. Mark current node as 'Synchronized'. 
                        # WARNING, Command changes Device Status to "Synchronized" without Data Synchronization with HA (High Availability) Partner, 
                        # Device will start processing Client Requests immediately and will be used as Data Synchronization Source for Partner Device.
                        #
                        #Write-Host "Device not synchronized. Mark current node as 'Synchronized'. " -foreground yellow

                        #$params = new-object -ComObject StarWindX.Parameters        
                        #$params.AppendParam("deviceID",$device.DeviceId)
                        
                        #$server.ExecuteCommand( 0, "restoreCurrentHANode", $params)
                        
                        Start-Sleep -m 5000
                    }
                }

                #
                # Refresh device info
                #
                $device.Refresh()

                Start-Sleep -m 1000
                
                $syncState = $device.GetPropertyValue("ha_synch_status")
            }
            
            Write-Host "Synchronization Status: Synchronized" -foreground yellow 

            break;
        }
    }
    
    if ( $deviceFound -ne $true )
    {
        Write-Host "$($deviceName) not found" -foreground red
    }
}
catch
{
    Write-Host "Exception $($_.Exception.Message)" -foreground red 
}

$server.Disconnect( )